@@ -4,7 +4,7 @@ use tvrank::imdb::{Imdb, ImdbQuery};
 
 fn main() -> tvrank::Res<()> {
   let cache_dir = tempfile::Builder::new().prefix("tvrank_").tempdir()?;
-  let imdb = Imdb::new(cache_dir.path(), false, &mut |_| {})?;
+  let imdb = Imdb::new(cache_dir.path(), false, &|_, _| {})?;
 
   let title = "city of god";
   let year = 2002;
