@@ -36,13 +36,15 @@ impl<T> From<TsvAction<T>> for Option<T> {
 
 /// Primary/original titles of a movie/series and its relevant information such as duration and rating
 #[derive(Debug, Clone, Copy, Serialize)]
-pub struct Title<'a> {
+pub struct Title<'storage> {
   #[serde(flatten)]
   header: TitleHeader,
+
   #[serde(flatten)]
-  title_id: TitleId<'a>,
-  primary_title: &'a str,
-  original_title: Option<&'a str>,
+  title_id: TitleId<'storage>,
+
+  primary_title: &'storage str,
+  original_title: Option<&'storage str>,
 }
 
 impl PartialEq for Title<'_> {
@@ -59,7 +61,7 @@ impl Hash for Title<'_> {
   }
 }
 
-impl<'a> Title<'a> {
+impl<'storage> Title<'storage> {
   /// Returns the id of the title
   pub fn title_id(&self) -> &TitleId {
     &self.title_id
@@ -112,7 +114,7 @@ impl<'a> Title<'a> {
   /// # Arguments
   /// * `line` - A title as tab separated values
   /// * `ratings` - Ratings struct containing the ratings of the titles
-  pub(crate) fn from_tsv(line: &'a [u8], ratings: &Ratings) -> Res<TsvAction<Self>> {
+  pub(crate) fn from_tsv(line: &'storage [u8], ratings: &Ratings) -> Res<TsvAction<Self>> {
     let mut columns = line.split(|&b| b == tokens::TAB);
 
     let title_id = TitleId::try_from(iter_next!(columns))?;
@@ -239,7 +241,7 @@ impl<'a> Title<'a> {
   /// Reads a title from its binary representation and returns it inside a Result
   /// # Arguments
   /// * `source` - Title to be read as binary
-  pub(crate) fn from_binary(source: &mut &'a [u8]) -> Res<Self> {
+  pub(crate) fn from_binary(source: &mut &'storage [u8]) -> Res<Self> {
     if (*source).len() < 23 {
       // # 23 bytes:
       //
@@ -299,9 +301,11 @@ impl<'a> Title<'a> {
 
 #[cfg(test)]
 mod test_title {
+  use super::Genre;
   use super::Rating;
   use super::Ratings;
   use super::Title;
+  use super::TitleType;
 
   #[test]
   fn test_title() {
@@ -316,6 +320,21 @@ mod test_title {
     let title: Option<Title> = title.into();
     let title = title.unwrap();
 
+    assert_eq!(title.title_id().as_str(), "tt0000001");
+    assert_eq!(title.title_type(), TitleType::Short);
+    assert_eq!(title.primary_title(), "Carmencita");
+    assert_eq!(title.original_title(), None);
+    assert!(!title.is_adult());
+    assert_eq!(title.start_year().unwrap(), 1894);
+    assert_eq!(title.runtime().unwrap().as_secs(), 60);
+
+    let mut genres_iter = title.genres().iter();
+    assert_eq!(genres_iter.next().unwrap(), Genre::Documentary);
+    assert_eq!(genres_iter.next().unwrap(), Genre::Short);
+
+    assert_eq!(title.rating().unwrap().rating(), 57);
+    assert_eq!(title.rating().unwrap().votes(), 1846);
+
     let mut binary = Vec::new();
     title.write_binary(&mut binary).unwrap();
 
